@@ -5,7 +5,7 @@ use Carp qw/croak carp/;
 use Scalar::Util qw/blessed weaken/;
 use Mojo::Base 'Mojo::DOM';
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 
 # Todo:
@@ -298,7 +298,7 @@ sub set {
   unshift(@_, $tag) unless blessed $_[0];
 
   # Add element (Maybe prefixed)
-  return $self->_add_clean(@_) or return;
+  return $self->_add_clean(@_);
 };
 
 
@@ -1419,7 +1419,8 @@ That said - it may not suit all your needs, but there are loads of excellent
 XML libraries out there, you can give a try then.
 Just to name a few: For fast parsing of huge documents, see L<XML::Twig>.
 For validation and the availability of lots of tools from the XML world,
-see L<XML::LibXML>.
+see L<XML::LibXML>. For simple deserialization,
+try L<XML::Bare> and L<XML::Fast>.
 
 
 =head1 AVAILABILITY
@@ -1429,7 +1430,7 @@ see L<XML::LibXML>.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011-2013, L<Nils Diewald|http://nils-diewald.de/>.
+Copyright (C) 2011-2014, L<Nils Diewald|http://nils-diewald.de/>.
 
 This program is free software, you can redistribute it
 and/or modify it under the same terms as Perl.
